@@ -3,9 +3,6 @@
 # Univention App Center
 #  univention-app module for updating the list of available apps
 #
-# Like what you see? Join us!
-# https://www.univention.com/about-us/careers/vacancies/
-#
 # SPDX-FileCopyrightText: 2015-2025 Univention GmbH
 # SPDX-License-Identifier: AGPL-3.0-only
 #
@@ -23,13 +20,16 @@ from urllib.request import Request
 from univention.appcenter.actions import UniventionAppAction, possible_network_error
 from univention.appcenter.app import LOCAL_ARCHIVE_DIR
 from univention.appcenter.app_cache import AppCenterCache, Apps
-from univention.appcenter.exceptions import UpdateSignatureVerificationFailed, UpdateUnpackArchiveFailed
+from univention.appcenter.exceptions import NetworkError, UpdateSignatureVerificationFailed, UpdateUnpackArchiveFailed
 from univention.appcenter.log import catch_stdout
 from univention.appcenter.ucr import ucr_is_false, ucr_save
 from univention.appcenter.utils import gpg_verify, mkdir, urlopen
 from univention.config_registry import handler_commit
 
 
+ETAGS_NAME = '.etags'
+
+
 class Update(UniventionAppAction):
     """Updates the list of all available applications by asking the App Center server"""
 
@@ -116,7 +116,7 @@ class Update(UniventionAppAction):
 
     def _save_etags(self, cache, etags):
         # type: (AppCenterCache, Mapping[str, str]) -> None
-        etags_file = os.path.join(cache.get_cache_dir(), '.etags')
+        etags_file = os.path.join(cache.get_cache_dir(), ETAGS_NAME)
         with open(etags_file, 'w') as f:
             f.writelines('%s\t%s\n' % (fname, etag) for fname, etag in etags.items())
 
@@ -129,7 +129,7 @@ class Update(UniventionAppAction):
         updated = False
         server = cache.get_server()
         cache_dir = cache.get_cache_dir()
-        etags_file = os.path.join(cache_dir, '.etags')
+        etags_file = os.path.join(cache_dir, ETAGS_NAME)
         present_etags = self._get_etags(etags_file)
         ucs_version = None
         if hasattr(cache, 'get_ucs_version'):
@@ -192,7 +192,17 @@ class Update(UniventionAppAction):
             #   * HTTP requests are altered
             self.warn('Downloading the App archive via zsync failed. Falling back to download it directly.')
             self.warn('For better performance, try to make zsync work for "%s". The error may be caused by a proxy altering HTTP requests' % all_tar_url)
-            self._download_files(app_cache, ['all.tar.gz'])
+            try:
+                self._download_files(app_cache, ['all.tar.gz'])
+            except NetworkError as exc:
+                # if we cannot download all.tar.gz, the .etags file is not valid anymore
+                # https://forge.univention.org/bugzilla/show_bug.cgi?id=58469
+                self.fatal('Failed to download all.tar.gz: %s' % exc)
+                if os.path.exists(os.path.join(cache_dir, ETAGS_NAME)):
+                    self.warn('Removing the old etags file %s' % os.path.join(cache_dir, ETAGS_NAME))
+                    # remove the old etags file, so that the next update will try to download it again
+                    os.unlink(os.path.join(cache_dir, ETAGS_NAME))
+                raise
             # files are always downloaded with their filename prepended by '.'
             tgz_file = os.path.join(cache_dir, '.all.tar.gz')
             self._uncompress_archive(app_cache, tgz_file)
